# remirepo spec file for php-pecl-crypto
#
# Copyright (c) 2013-2024 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

%{?scl:%scl_package php-pecl-crypto}

%bcond_without      tests
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name   crypto
%if "%{php_version}" < "5.6"
%global ini_name    %{pecl_name}.ini
%else
%global ini_name    40-%{pecl_name}.ini
%endif
%global sources     %{pecl_name}-%{version}
%global _configure  ../%{sources}/configure

Summary:        Wrapper for OpenSSL Crypto Library
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        0.3.2
Release:        4%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        PHP-3.01
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{sources}.tgz

Patch0:         0001-Fix-Wincompatible-pointer-types.patch
Patch1:         0001-fix-for-PHP-8.4.patch

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel
BuildRequires:  %{?scl_prefix}php-pear
# don't use pkg-config to avoid compat-openssl10
BuildRequires:  openssl-devel

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-%{pecl_name} = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa} = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name}) = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
This package provides an objective wrapper for OpenSSL Crypto Library.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

cd %{sources}
%patch -P0 -p1
%patch -P1 -p1

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_CRYPTO_VERSION/{s/.* "//;s/".*$//;p}' php_crypto.h)
if test "x${extver}" != "x%{version}%{?prever:-%{prever}}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?prever:-%{prever}}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable '%{summary}' extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}
[ -f Makefile.global ] && GLOBAL=Makefile.global || GLOBAL=build/Makefile.global
sed -e 's/INSTALL_ROOT/DESTDIR/' -i $GLOBAL

cd ../NTS
%configure \
    --with-crypto \
    --with-php-config=%{__phpconfig}

%make_build

%if %{with_zts}
cd ../ZTS
%configure \
    --with-crypto \
    --with-php-config=%{__ztsphpconfig}

%make_build
%endif


%install
%{?dtsenable}

%make_install -C NTS

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
%make_install -C ZTS

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
cd %{sources}

: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=$PWD/../NTS/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php -q --show-diff
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}//%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite for ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n -d extension=$PWD/../ZTS/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php -q --show-diff
%endif
%endif


%files
%license %{sources}/LICENSE
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml
%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif



%changelog
* Wed Sep 25 2024 Remi Collet <remi@remirepo.net> - 0.3.2-4
- fix build with PHP 8.4 using patch from
  https://github.com/bukka/php-crypto/pull/42

* Fri Feb 16 2024 Remi Collet <remi@remirepo.net> - 0.3.2-3
- fix [-Wincompatible-pointer-types] using patch from
  https://github.com/bukka/php-crypto/pull/40

* Thu Aug 31 2023 Remi Collet <remi@remirepo.net> - 0.3.2-2
- build out of sources tree

* Mon Mar  8 2021 Remi Collet <remi@remirepo.net> - 0.3.2-1
- update to 0.3.2

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 0.3.1-9
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 0.3.1-8
- rebuild for 7.4.0beta1

* Tue Dec  4 2018 Remi Collet <remi@remirepo.net> - 0.3.1-7
- EL-8 build

* Wed Aug 22 2018 Remi Collet <remi@remirepo.net> - 0.3.1-6
- ignore 2 tests on F29

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 0.3.1-5
- rebuild for 7.3.0beta2 new ABI

* Tue Jul 17 2018 Remi Collet <remi@remirepo.net> - 0.3.1-4
- rebuld for 7.3.0alpha4 new ABI

* Wed Jan 31 2018 Remi Collet <remi@remirepo.net> - 0.3.1-3
- ensure OpenSSL 1.1 is used on F26+

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 0.3.1-2
- rebuild for PHP 7.2.0beta1 new API

* Fri Dec 16 2016 Remi Collet <remi@fedoraproject.org> - 0.3.1-1
- Update to 0.3.1
- drop patch merged upstream

* Thu Dec 15 2016 Remi Collet <remi@fedoraproject.org> - 0.3.0-1
- Update to 0.3.0
- open https://github.com/bukka/php-crypto/issues/19 segfault
- open https://github.com/bukka/php-crypto/pull/20 fix for PHP 5

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 0.2.2-5
- rebuild with PHP 7.1.0 GA

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 0.2.2-4
- rebuild for PHP 7.1 new API version

* Thu Jun  9 2016 Remi Collet <remi@fedoraproject.org> - 0.2.2-3
- add upstream patch for PHP 7.1

* Sat Mar  5 2016 Remi Collet <remi@fedoraproject.org> - 0.2.2-2
- adapt for F24

* Wed Nov 25 2015 Remi Collet <remi@fedoraproject.org> - 0.2.2-1
- Update to 0.2.2

* Mon Nov 16 2015 Remi Collet <remi@fedoraproject.org> - 0.2.1-1
- Update to 0.2.1
- don't install/register tests
- drop runtime dependency on pear, new scriptlets
- improve skip check for CCM test when not available
  open https://github.com/bukka/php-crypto/pull/13
- allow to build as more-php56 for rh-php56

* Wed Dec 24 2014 Remi Collet <remi@fedoraproject.org> - 0.1.1-3.1
- Fedora 21 SCL mass rebuild

* Tue Aug 26 2014 Remi Collet <rcollet@redhat.com> - 0.1.1-3
- improve SCL build

* Tue Apr 15 2014 Remi Collet <remi@fedoraproject.org> - 0.1.1-2
- add numerical prefix to extension configuration file

* Sat Jan 04 2014 Remi Collet <remi@fedoraproject.org> - 0.1.1-1
- Update to 0.1.1 (devel)
- drop patch merged upstream

* Thu Jan  2 2014 Remi Collet <remi@fedoraproject.org> - 0.1.0-1
- initial package, version 0.1.0 (devel)
- patch for PHP 5.3.3, https://github.com/bukka/php-crypto/pull/6

